==> qmmp-plugin-pack-0.10.3.tar.bz2: qmmp-plugin-pack-0.10.3/src/Input/xmp/translations/xmp_plugin_he.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="he">
<context>
    <name>DecoderXmpFactory</name>
    <message>
        <location filename="../decoderxmpfactory.cpp" line="53"/>
        <source>XMP Plugin</source>
        <translation>תוסף XMP</translation>
    </message>
    <message>
        <location filename="../decoderxmpfactory.cpp" line="67"/>
        <source>Module Files</source>
        <translation>קבצי מודול</translation>
    </message>
    <message>
        <location filename="../decoderxmpfactory.cpp" line="122"/>
        <source>About XMP Audio Plugin</source>
        <translation>אודות תוסף XMP שמע</translation>
    </message>
    <message>
        <location filename="../decoderxmpfactory.cpp" line="123"/>
        <source>Qmmp XMP Audio Plugin</source>
        <translation>תוסף XMP שמע של Qmmp</translation>
    </message>
    <message>
        <location filename="../decoderxmpfactory.cpp" line="124"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>חובר על ידי: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;‎</translation>
    </message>
    <message>
        <location filename="../decoderxmpfactory.cpp" line="125"/>
        <source>Compiled against libxmp-%1</source>
        <translation>הודרה כנגד libxmp-%1</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>XMP Plugin Settings</source>
        <translation>הגדרות תוסף XMP</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="34"/>
        <source> Amplification factor:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="51"/>
        <source>Stereo mixing:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="68"/>
        <source> Interpolation type:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="78"/>
        <source>Lowpass filter effect</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="85"/>
        <source>Use vblank timing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="92"/>
        <source>Emulate Protracker 2.x FX9 bug</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="99"/>
        <source>Sample rate:</source>
        <translation>שיעור דגימה:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="33"/>
        <source>22050 Hz</source>
        <translation>22050 הרץ</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="34"/>
        <source>44100 Hz</source>
        <translation>44100 הרץ</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="35"/>
        <source>48000 Hz</source>
        <translation>48000 הרץ</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="36"/>
        <source>Nearest neighbor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="37"/>
        <source>Linear</source>
        <translation>לינארית</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="38"/>
        <source>Cubic spline</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>XmpMetaDataModel</name>
    <message>
        <location filename="../xmpmetadatamodel.cpp" line="49"/>
        <source>File name</source>
        <translation>שם קובץ</translation>
    </message>
    <message>
        <location filename="../xmpmetadatamodel.cpp" line="54"/>
        <source>Format</source>
        <translation>פורמט</translation>
    </message>
    <message>
        <location filename="../xmpmetadatamodel.cpp" line="55"/>
        <source>Volume scale</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../xmpmetadatamodel.cpp" line="56"/>
        <source>Number of patterns</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../xmpmetadatamodel.cpp" line="57"/>
        <source>Number of tracks</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../xmpmetadatamodel.cpp" line="58"/>
        <source>Tracks per pattern</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../xmpmetadatamodel.cpp" line="59"/>
        <source>Number of instruments</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../xmpmetadatamodel.cpp" line="60"/>
        <source>Number of samples</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../xmpmetadatamodel.cpp" line="61"/>
        <source>Initial speed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../xmpmetadatamodel.cpp" line="62"/>
        <source>Initial BPM</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../xmpmetadatamodel.cpp" line="63"/>
        <source>Module length in patterns</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../xmpmetadatamodel.cpp" line="82"/>
        <source>Samples</source>
        <translation>דגימות</translation>
    </message>
    <message>
        <location filename="../xmpmetadatamodel.cpp" line="90"/>
        <source>Instruments</source>
        <translation>מכשירים</translation>
    </message>
    <message>
        <location filename="../xmpmetadatamodel.cpp" line="95"/>
        <source>Comment</source>
        <translation>הערה</translation>
    </message>
</context>
</TS>

==> qmmp-plugin-pack-0.12.2.tar.bz2: qmmp-plugin-pack-0.12.2/src/Input/xmp/translations/xmp_plugin_he.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="he">
<context>
    <name>DecoderXmpFactory</name>
    <message>
        <location filename="../decoderxmpfactory.cpp" line="41"/>
        <source>XMP Plugin</source>
        <translation>תוסף XMP</translation>
    </message>
    <message>
        <location filename="../decoderxmpfactory.cpp" line="55"/>
        <source>Module Files</source>
        <translation>קבצי מודול</translation>
    </message>
    <message>
        <location filename="../decoderxmpfactory.cpp" line="112"/>
        <source>About XMP Audio Plugin</source>
        <translation>אודות תוסף XMP שמע</translation>
    </message>
    <message>
        <location filename="../decoderxmpfactory.cpp" line="113"/>
        <source>Qmmp XMP Audio Plugin</source>
        <translation>תוסף XMP שמע של Qmmp</translation>
    </message>
    <message>
        <location filename="../decoderxmpfactory.cpp" line="114"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../decoderxmpfactory.cpp" line="115"/>
        <source>Compiled against libxmp-%1</source>
        <translation>הודרה כנגד libxmp-%1</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>XMP Plugin Settings</source>
        <translation>הגדרות תוסף XMP</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="34"/>
        <source> Amplification factor:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="51"/>
        <source>Stereo mixing:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="68"/>
        <source> Interpolation type:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="78"/>
        <source>Lowpass filter effect</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="85"/>
        <source>Use vblank timing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="92"/>
        <source>Emulate Protracker 2.x FX9 bug</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="99"/>
        <source>Sample rate:</source>
        <translation>שיעור דגימה:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="33"/>
        <source>22050 Hz</source>
        <translation>22050 הרץ</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="34"/>
        <source>44100 Hz</source>
        <translation>44100 הרץ</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="35"/>
        <source>48000 Hz</source>
        <translation>48000 הרץ</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="36"/>
        <source>Nearest neighbor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="37"/>
        <source>Linear</source>
        <translation>לינארית</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="38"/>
        <source>Cubic spline</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>XmpMetaDataModel</name>
    <message>
        <location filename="../xmpmetadatamodel.cpp" line="53"/>
        <source>Volume scale</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../xmpmetadatamodel.cpp" line="54"/>
        <source>Number of patterns</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../xmpmetadatamodel.cpp" line="55"/>
        <source>Number of tracks</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../xmpmetadatamodel.cpp" line="56"/>
        <source>Tracks per pattern</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../xmpmetadatamodel.cpp" line="57"/>
        <source>Number of instruments</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../xmpmetadatamodel.cpp" line="58"/>
        <source>Number of samples</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../xmpmetadatamodel.cpp" line="59"/>
        <source>Initial speed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../xmpmetadatamodel.cpp" line="60"/>
        <source>Initial BPM</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../xmpmetadatamodel.cpp" line="61"/>
        <source>Module length in patterns</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../xmpmetadatamodel.cpp" line="80"/>
        <source>Samples</source>
        <translation>דגימות</translation>
    </message>
    <message>
        <location filename="../xmpmetadatamodel.cpp" line="88"/>
        <source>Instruments</source>
        <translation>מכשירים</translation>
    </message>
    <message>
        <location filename="../xmpmetadatamodel.cpp" line="93"/>
        <source>Comment</source>
        <translation>הערה</translation>
    </message>
</context>
</TS>
